function [error_all, recall_all, precision_all, length_all, accuracy_all, time_all, K_all] = performance_on_benchmark(truthpath, outpath)

if truthpath(end) ~= '/'
    truthpath(end+1) = '/';
end
if outpath(end) ~= '/'
    outpath(end+1) = '/';
end

segs = dir([truthpath '*.mat']);

disp(['*** ' outpath ' ***']);
for i = 1:length(segs)
    disp(['  Image ' num2str(i)]);
    
    clear error recall precision blength accuracy;
    is_updated = false;
    
    segname = segs(i).name;
    load([truthpath segname]);
    load([outpath segname]);
    
    if ~exist('error', 'var')
        error = undersegmentation_error(groundTruth, prediction);
        is_updated = true;
    end
    if ~exist('blength', 'var')
        [recall, precision, blength] = boundary_measure(groundTruth, prediction);
        is_updated = true;
    end
    if ~exist('accuracy', 'var')
        accuracy = segmentation_accuracy(groundTruth, prediction);
        is_updated = true;
    end
    
    if (i==1)
        NK = length(prediction);
        error_all = zeros(length(segs), NK);
        recall_all = zeros(length(segs), NK);
        precision_all = zeros(length(segs), NK);
        length_all = zeros(length(segs), NK);
        accuracy_all = zeros(length(segs), NK);
        time_all = zeros(length(segs), NK);
        K_all = zeros(length(segs), NK);
    end
    
    error_all(i,:) = mean(error,1);
    recall_all(i,:) = mean(recall,1);
    precision_all(i,:) = mean(precision,1);
    accuracy_all(i,:) = mean(accuracy,1);
    length_all(i,:) = blength;
    for j = 1:NK
        time_all(i,j) = prediction{j}.Time;
        K_all(i,j) = prediction{j}.K;
    end
    
    if is_updated
        save([outpath segname], 'prediction', 'error', 'recall', 'precision', 'blength', 'accuracy', '-v7.3');
    end
end
