close all;
show_std = false;

methods = {'mmlp'};
legend_names = {'MMLP'};
mcolors = {[1 0 0]};
x_lim = [50 500];

truthpath = '../BSR/BSDS500/data/groundTruth/test';
for m=1:length(methods)
    method = methods{m};
    outpath = sprintf('./out/%s/',method);
    outvars = sprintf('[%s_error, %s_recall, %s_precision, %s_length, %s_accuracy, %s_time, %s_K]',method,method,method,method,method,method,method);
    evalcommand = sprintf('%s = performance_on_benchmark(truthpath, outpath);',outvars);
    eval(evalcommand);
end

%% Under-segmentation error
figure('Units','inches','PaperPosition',[10 5 12 10], 'PaperPositionMode','manual');
hold on;

for m=1:length(methods)
    method = methods{m};
    px = mean(eval([method '_K']));
    py = mean(eval([method '_error']));
    
    col = mcolors{m};
    plot(px, py, 'Color', col, 'LineWidth',3);
    if(show_std)
        pl = std(eval([method '_error']));
        plot(px, py+pl, [col '+'], 'LineWidth',1);
        plot(px, py-pl, [col '+'], 'LineWidth',1);
        line([px; px], [py+pl; py-pl], 'color',col, 'LineWidth',1);
    end
    xlim(x_lim);
    ylim([0.15 0.65]);
end

legend(legend_names,'fontsize',12);
xlabel('Number of segmentations','fontsize',10);
ylabel('Under-segmentation error','fontsize',10);
grid on;
hold off;
clear px py pl col;

print -depsc plots/error;

%% Boundary recall
figure('Units','inches','PaperPosition',[10 5 12 10], 'PaperPositionMode','manual');
hold on;

for m=1:length(methods)
    method = methods{m};
    
    px = mean(eval([method '_K']));
    py = mean(eval([method '_recall']));
    
    col = mcolors{m};
    plot(px, py, 'Color', col, 'LineWidth',3);
    if(show_std)
        pl = std(eval([method '_recall']));
        plot(px, py+pl, [col '+'], 'LineWidth',1);
        plot(px, py-pl, [col '+'], 'LineWidth',1);
        line([px; px], [py+pl; py-pl], 'color',col, 'LineWidth',1);
    end
    xlim(x_lim);
    ylim([0.6 1]);
end

legend(legend_names,'fontsize',12,'location','northwest');
xlabel('Number of segmentations','fontsize',10);
ylabel('Boundary recall','fontsize',10);
grid on;
hold off;
clear px py pl col;

print -depsc plots/recall;

%% Boundary precision
figure('Units','inches','PaperPosition',[10 5 12 10], 'PaperPositionMode','manual');
hold on;

for m=1:length(methods)
    method = methods{m};
    px = mean(eval([method '_K']));
    py = mean(eval([method '_precision']));
    
    col = mcolors{m};
    plot(px, py, 'Color', col, 'LineWidth',3);
    if(show_std)
        pl = std(eval([method '_precision']));
        plot(px, py+pl, [col '+'], 'LineWidth',1);
        plot(px, py-pl, [col '+'], 'LineWidth',1);
        line([px; px], [py+pl; py-pl], 'color',col, 'LineWidth',1);
    end
    xlim(x_lim);
    ylim([0.14 0.350001]);
end

legend(legend_names,'fontsize',12);
xlabel('Number of segmentations','fontsize',10);
ylabel('Boundary precision','fontsize',10);
grid on;
hold off;
clear px py pl col;

print -depsc plots/precision;

%% Boundary F-measure
figure('Units','inches','PaperPosition',[10 5 12 10], 'PaperPositionMode','manual');
hold on;

for m=1:length(methods)
    method = methods{m};
    px = mean(eval([method '_K']));
    p = mean(eval([method '_precision']));
    r = mean(eval([method '_recall']));
    py = 2./(1./p+1./r);
    
    col = mcolors{m};
    plot(px, py, 'Color', col, 'LineWidth',3);
    xlim(x_lim);
    ylim([0.25 0.5]);
end

legend(legend_names,'fontsize',12);
xlabel('Number of segmentations','fontsize',10);
ylabel('Boundary F_measure','fontsize',10);
grid on;
hold off;
clear px py pl col;

print -depsc plots/f-measure;

%% Achievable segmentation accuracy
figure('Units','inches','PaperPosition',[10 5 12 10], 'PaperPositionMode','manual');
hold on;

for m=1:length(methods)
    method = methods{m};
    px = mean(eval([method '_K']));
    py = mean(eval([method '_accuracy']));
    col = mcolors{m};
    plot(px, py, 'Color', col, 'LineWidth',3);
    if(show_std)
        pl = std(eval([method '_accuracy']));
        plot(px, py+pl, [col '+'], 'LineWidth',1);
        plot(px, py-pl, [col '+'], 'LineWidth',1);
        line([px; px], [py+pl; py-pl], 'color',col, 'LineWidth',1);
    end
    xlim(x_lim);
    ylim([0.92 0.99]);
end

legend(legend_names,'fontsize',12,'location','southeast');
xlabel('Number of segmentations','fontsize',10);
ylabel('Achievable segmentation accuracy','fontsize',10);
grid on;
hold off;
clear px py pl col;

print -depsc plots/accuracy;

%% Running time
figure('Units','inches','PaperPosition',[10 5 12 10], 'PaperPositionMode','manual');
hold on;

for m=1:length(methods)
    method = methods{m};
    px = mean(eval([method '_K']));
    py = mean(eval([method '_time']));
    
    col = mcolors{m};
    plot(px, py, 'Color', col, 'LineWidth',3);
    if(show_std)
        pl = std(eval([method '_time']));
        plot(px, py+pl, [col '+'], 'LineWidth',1);
        plot(px, py-pl, [col '+'], 'LineWidth',1);
        line([px; px], [py+pl; py-pl], 'color',col, 'LineWidth',1);
    end
    xlim(x_lim);
    ylim([0 1.6]);
end

legend(legend_names,'fontsize',12);
xlabel('Number of segmentations','fontsize',10);
ylabel('Running time (seconds)','fontsize',10);
grid on;
hold off;
clear px py pl col;

print -depsc plots/speed;